@@ -1,5 +1,5 @@
 /*
- * Copyright 2003-2017 The Music Player Daemon Project
+ * Copyright 2003-2018 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,7 @@
 #include <stdlib.h>
 
 AllocatedString<>
-FormatStringV(const char *fmt, va_list args)
+FormatStringV(const char *fmt, va_list args) noexcept
 {
 	va_list tmp;
 	va_copy(tmp, args);
@@ -41,7 +41,7 @@ FormatStringV(const char *fmt, va_list args)
 }
 
 AllocatedString<>
-FormatString(const char *fmt, ...)
+FormatString(const char *fmt, ...) noexcept
 {
 	va_list args;
 	va_start(args, fmt);
